"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const target = require("../../constants/target.qwik.cjs");
const isBrowser = require("../../functions/is-browser.qwik.cjs");
const isEditing = require("../../functions/is-editing.qwik.cjs");
const inlinedFns = require("./helpers/inlined-fns.qwik.cjs");
const DEFAULT_INDEX = "default";
const FILTER_WITH_CUSTOM_TARGETING_SCRIPT_FN_NAME = "filterWithCustomTargeting";
const BUILDER_IO_PERSONALIZATION_SCRIPT_FN_NAME = "builderIoPersonalization";
const UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME = "updateVisibilityStylesScript";
const SDKS_SUPPORTING_PERSONALIZATION = [
  "react",
  "vue",
  "svelte"
];
const SDKS_REQUIRING_RESET_APPROACH = [
  "vue",
  "svelte"
];
function checkShouldRenderVariants(variants, canTrack) {
  const hasVariants = variants && variants.length > 0;
  if (!hasVariants)
    return false;
  if (!canTrack)
    return false;
  if (SDKS_REQUIRING_RESET_APPROACH.includes(target.TARGET))
    return true;
  if (isBrowser.isBrowser())
    return false;
  return true;
}
function getBlocksToRender({ variants, previewingIndex, isHydrated, filteredVariants, fallbackBlocks }) {
  const fallback = {
    blocks: fallbackBlocks ?? [],
    path: "this.children",
    index: DEFAULT_INDEX
  };
  if (isHydrated && isEditing.isEditing()) {
    if (typeof previewingIndex === "number" && previewingIndex < ((variants == null ? void 0 : variants.length) ?? 0)) {
      const variant = variants == null ? void 0 : variants[previewingIndex];
      if (variant)
        return {
          blocks: variant.blocks,
          path: `variants.${previewingIndex}.blocks`,
          index: previewingIndex
        };
    }
    return fallback;
  }
  if (isBrowser.isBrowser()) {
    const winningVariant = filteredVariants == null ? void 0 : filteredVariants[0];
    if (winningVariant && variants) {
      const variantIndex = variants.indexOf(winningVariant);
      if (variantIndex !== -1)
        return {
          blocks: winningVariant.blocks,
          path: `variants.${variantIndex}.blocks`,
          index: variantIndex
        };
    }
  }
  return fallback;
}
const getInitPersonalizationVariantsFnsScriptString = () => {
  return `
  window.${FILTER_WITH_CUSTOM_TARGETING_SCRIPT_FN_NAME} = ${inlinedFns.FILTER_WITH_CUSTOM_TARGETING_SCRIPT}
  window.${BUILDER_IO_PERSONALIZATION_SCRIPT_FN_NAME} = ${inlinedFns.PERSONALIZATION_SCRIPT}
  window.${UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME} = ${inlinedFns.UPDATE_VISIBILITY_STYLES_SCRIPT}
  `;
};
const isHydrationTarget = target.TARGET === "react";
const getPersonalizationScript = (variants, blockId, locale) => {
  return `window.${BUILDER_IO_PERSONALIZATION_SCRIPT_FN_NAME}(${JSON.stringify(variants)}, "${blockId}", ${isHydrationTarget}${locale ? `, "${locale}"` : ""})`;
};
const getUpdateVisibilityStylesScript = (variants, blockId, locale) => {
  return `window.${UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME}(${JSON.stringify(variants)}, "${blockId}", ${isHydrationTarget}${locale ? `, "${locale}"` : ""})`;
};
exports.filterWithCustomTargeting = inlinedFns.filterWithCustomTargeting;
exports.DEFAULT_INDEX = DEFAULT_INDEX;
exports.SDKS_REQUIRING_RESET_APPROACH = SDKS_REQUIRING_RESET_APPROACH;
exports.SDKS_SUPPORTING_PERSONALIZATION = SDKS_SUPPORTING_PERSONALIZATION;
exports.checkShouldRenderVariants = checkShouldRenderVariants;
exports.getBlocksToRender = getBlocksToRender;
exports.getInitPersonalizationVariantsFnsScriptString = getInitPersonalizationVariantsFnsScriptString;
exports.getPersonalizationScript = getPersonalizationScript;
exports.getUpdateVisibilityStylesScript = getUpdateVisibilityStylesScript;
